@@ -31,6 +31,7 @@ class DataConfig:
         self,
         s3_data_input_path,
         s3_output_path,
+        s3_analysis_config_output_path=None,
         label=None,
         headers=None,
         features=None,
@@ -43,6 +44,9 @@ class DataConfig:
         Args:
             s3_data_input_path (str): Dataset S3 prefix/object URI.
             s3_output_path (str): S3 prefix to store the output.
+            s3_analysis_config_output_path (str): S3 prefix to store the analysis_config output
+                If this field is None, then the s3_output_path will be used
+                to store the analysis_config output
             label (str): Target attribute of the model required by bias metrics (optional for SHAP)
                 Specified as column name or index for CSV dataset, or as JSONPath for JSONLines.
             headers (list[str]): A list of column names in the input dataset.
@@ -61,6 +65,7 @@ class DataConfig:
             )
         self.s3_data_input_path = s3_data_input_path
         self.s3_output_path = s3_output_path
+        self.s3_analysis_config_output_path = s3_analysis_config_output_path
         self.s3_data_distribution_type = s3_data_distribution_type
         self.s3_compression_type = s3_compression_type
         self.label = label
@@ -228,7 +233,7 @@ class ModelPredictedLabelConfig:
         probability_threshold=None,
         label_headers=None,
     ):
-        """Initializes a model output config to extract the predicted label.
+        """Initializes a model output config to extract the predicted label or predicted score(s).
 
         The following examples show different parameter configurations depending on the endpoint:
             * Regression Task: The model returns the score, e.g. 1.2. we don't need to specify
@@ -255,11 +260,11 @@ class ModelPredictedLabelConfig:
                     'label_headers=['cat','dog','fish']' and infer the predicted label to be 'fish.'
 
         Args:
-            label (str or int or list[int]): Optional index or JSONPath location in the model
-                output for the prediction. In case, this is a predicted label of the same type as
-                the label in the dataset no further arguments need to be specified.
-            probability (str or int or list[int]): Optional index or JSONPath location in the model
-                output for the predicted scores.
+            label (str or int): Index or JSONPath location in the model output for the prediction.
+                In case, this is a predicted label of the same type as the label in the dataset,
+                no further arguments need to be specified.
+            probability (str or int): Index or JSONPath location in the model output
+                for the predicted score(s).
             probability_threshold (float): An optional value for binary prediction tasks in which
                 the model returns a probability, to indicate the threshold to convert the
                 prediction to a boolean value. Default is 0.5.
@@ -473,7 +478,7 @@ class SageMakerClarifyProcessor(Processor):
                 json.dump(analysis_config, f)
             s3_analysis_config_file = _upload_analysis_config(
                 analysis_config_file,
-                data_config.s3_output_path,
+                data_config.s3_analysis_config_output_path or data_config.s3_output_path,
                 self.sagemaker_session,
                 kms_key,
             )
