@@ -41,6 +41,7 @@ from sagemaker.workflow.properties import (
     Properties,
 )
 from sagemaker.workflow.functions import Join
+from sagemaker.workflow.retry import RetryPolicy
 
 
 class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
@@ -68,6 +69,7 @@ class Step(Entity):
         step_type (StepTypeEnum): The type of the step.
         depends_on (List[str] or List[Step]): The list of step names or step
             instances the current step depends on
+        retry_policies (List[RetryPolicy]): The custom retry policy configuration
     """
 
     name: str = attr.ib(factory=str)
@@ -99,6 +101,7 @@ class Step(Entity):
             request_dict["DisplayName"] = self.display_name
         if self.description:
             request_dict["Description"] = self.description
+
         return request_dict
 
     def add_depends_on(self, step_names: Union[List[str], List["Step"]]):
@@ -117,8 +120,8 @@ class Step(Entity):
         return {"Name": self.name}
 
     @staticmethod
-    def _resolve_depends_on(depends_on_list: Union[List[str], List["Step"]]):
-        """Resolver the step depends on list"""
+    def _resolve_depends_on(depends_on_list: Union[List[str], List["Step"]]) -> List[str]:
+        """Resolve the step depends on list"""
         depends_on = []
         for step in depends_on_list:
             if isinstance(step, Step):
@@ -168,7 +171,50 @@ class CacheConfig:
         return {"CacheConfig": config}
 
 
-class TrainingStep(Step):
+class ConfigurableRetryStep(Step):
+    """ConfigurableRetryStep step for workflow."""
+
+    def __init__(
+        self,
+        name: str,
+        step_type: StepTypeEnum,
+        display_name: str = None,
+        description: str = None,
+        depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
+    ):
+        super().__init__(
+            name=name,
+            display_name=display_name,
+            step_type=step_type,
+            description=description,
+            depends_on=depends_on,
+        )
+        self.retry_policies = [] if not retry_policies else retry_policies
+
+    def add_retry_policy(self, retry_policy: RetryPolicy):
+        """Add a retry policy to the current step retry policies list."""
+        if not retry_policy:
+            return
+
+        if not self.retry_policies:
+            self.retry_policies = []
+        self.retry_policies.append(retry_policy)
+
+    def to_request(self) -> RequestType:
+        """Gets the request structure for ConfigurableRetryStep"""
+        step_dict = super().to_request()
+        if self.retry_policies:
+            step_dict["RetryPolicies"] = self._resolve_retry_policy(self.retry_policies)
+        return step_dict
+
+    @staticmethod
+    def _resolve_retry_policy(retry_policy_list: List[RetryPolicy]) -> List[RequestType]:
+        """Resolve the step retry policy list"""
+        return [retry_policy.to_request() for retry_policy in retry_policy_list]
+
+
+class TrainingStep(ConfigurableRetryStep):
     """Training step for workflow."""
 
     def __init__(
@@ -180,6 +226,7 @@ class TrainingStep(Step):
         inputs: Union[TrainingInput, dict, str, FileSystemInput] = None,
         cache_config: CacheConfig = None,
         depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
     ):
         """Construct a TrainingStep, given an `EstimatorBase` instance.
 
@@ -210,9 +257,10 @@ class TrainingStep(Step):
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
             depends_on (List[str] or List[Step]): A list of step names or step instances
                 this `sagemaker.workflow.steps.TrainingStep` depends on
+            retry_policies (List[RetryPolicy]):  A list of retry policy
         """
         super(TrainingStep, self).__init__(
-            name, display_name, description, StepTypeEnum.TRAINING, depends_on
+            name, StepTypeEnum.TRAINING, display_name, description, depends_on, retry_policies
         )
         self.estimator = estimator
         self.inputs = inputs
@@ -252,7 +300,7 @@ class TrainingStep(Step):
         return request_dict
 
 
-class CreateModelStep(Step):
+class CreateModelStep(ConfigurableRetryStep):
     """CreateModel step for workflow."""
 
     def __init__(
@@ -261,6 +309,7 @@ class CreateModelStep(Step):
         model: Model,
         inputs: CreateModelInput,
         depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
         display_name: str = None,
         description: str = None,
     ):
@@ -276,11 +325,12 @@ class CreateModelStep(Step):
                 Defaults to `None`.
             depends_on (List[str] or List[Step]): A list of step names or step instances
                 this `sagemaker.workflow.steps.CreateModelStep` depends on
+            retry_policies (List[RetryPolicy]):  A list of retry policy
             display_name (str): The display name of the CreateModel step.
             description (str): The description of the CreateModel step.
         """
         super(CreateModelStep, self).__init__(
-            name, display_name, description, StepTypeEnum.CREATE_MODEL, depends_on
+            name, StepTypeEnum.CREATE_MODEL, display_name, description, depends_on, retry_policies
         )
         self.model = model
         self.inputs = inputs or CreateModelInput()
@@ -315,7 +365,7 @@ class CreateModelStep(Step):
         return self._properties
 
 
-class TransformStep(Step):
+class TransformStep(ConfigurableRetryStep):
     """Transform step for workflow."""
 
     def __init__(
@@ -327,6 +377,7 @@ class TransformStep(Step):
         description: str = None,
         cache_config: CacheConfig = None,
         depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
     ):
         """Constructs a TransformStep, given an `Transformer` instance.
 
@@ -342,9 +393,10 @@ class TransformStep(Step):
             description (str): The description of the transform step.
             depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TransformStep`
                 depends on
+            retry_policies (List[RetryPolicy]):  A list of retry policy
         """
         super(TransformStep, self).__init__(
-            name, display_name, description, StepTypeEnum.TRANSFORM, depends_on
+            name, StepTypeEnum.TRANSFORM, display_name, description, depends_on, retry_policies
         )
         self.transformer = transformer
         self.inputs = inputs
@@ -393,7 +445,7 @@ class TransformStep(Step):
         return request_dict
 
 
-class ProcessingStep(Step):
+class ProcessingStep(ConfigurableRetryStep):
     """Processing step for workflow."""
 
     def __init__(
@@ -409,6 +461,7 @@ class ProcessingStep(Step):
         property_files: List[PropertyFile] = None,
         cache_config: CacheConfig = None,
         depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
     ):
         """Construct a ProcessingStep, given a `Processor` instance.
 
@@ -433,9 +486,10 @@ class ProcessingStep(Step):
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
             depends_on (List[str] or List[Step]): A list of step names or step instance
                 this `sagemaker.workflow.steps.ProcessingStep` depends on
+            retry_policies (List[RetryPolicy]):  A list of retry policy
         """
         super(ProcessingStep, self).__init__(
-            name, display_name, description, StepTypeEnum.PROCESSING, depends_on
+            name, StepTypeEnum.PROCESSING, display_name, description, depends_on, retry_policies
         )
         self.processor = processor
         self.inputs = inputs
@@ -492,7 +546,7 @@ class ProcessingStep(Step):
         return request_dict
 
 
-class TuningStep(Step):
+class TuningStep(ConfigurableRetryStep):
     """Tuning step for workflow."""
 
     def __init__(
@@ -505,6 +559,7 @@ class TuningStep(Step):
         job_arguments: List[str] = None,
         cache_config: CacheConfig = None,
         depends_on: Union[List[str], List[Step]] = None,
+        retry_policies: List[RetryPolicy] = None,
     ):
         """Construct a TuningStep, given a `HyperparameterTuner` instance.
 
@@ -548,9 +603,10 @@ class TuningStep(Step):
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
             depends_on (List[str] or List[Step]): A list of step names or step instance
                 this `sagemaker.workflow.steps.ProcessingStep` depends on
+            retry_policies (List[RetryPolicy]):  A list of retry policy
         """
         super(TuningStep, self).__init__(
-            name, display_name, description, StepTypeEnum.TUNING, depends_on
+            name, StepTypeEnum.TUNING, display_name, description, depends_on, retry_policies
         )
         self.tuner = tuner
         self.inputs = inputs
